@@ -1,4 +1,29 @@
+/* gnome-hint.c - 
+
+   This file is part of the Gnome Library.
+
+   The Gnome Library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Library General Public License as
+   published by the Free Software Foundation; either version 2 of the
+   License, or (at your option) any later version.
+   
+   The Gnome Library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
+   
+   You should have received a copy of the GNU Library General Public
+   License along with the Gnome Library; see the file COPYING.LIB.  If not,
+   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.  */
+
 #include <config.h>
+
+#ifndef GNOME_DISABLE_DEPRECATED_SOURCE
+
+#undef GNOME_DISABLE_DEPRECATED
+#undef GTK_DISABLE_DEPRECATED
+
 #include <libgnome/libgnome.h>
 #include <libgnomeui/libgnomeui.h>
 #include <libgnomeui/gnome-hint.h>
@@ -124,7 +149,7 @@ gnome_hint_finalize (GObject *object)
 	gnome_hint = GNOME_HINT (object);
 
 	for (l = gnome_hint->_priv->hintlist; l; l = l->next)
-		g_free (l->data);
+		xmlFree (l->data);
 	g_list_free (gnome_hint->_priv->hintlist);
 
 	g_free (gnome_hint->_priv->startupkey);
@@ -217,10 +242,10 @@ find_lang (const char * const *langs_pointer, const char *gotlang, const char *l
 }
 
 /*parse all children and pick out the best language one*/
-static char *
+static xmlChar *
 get_i18n_string (xmlDocPtr doc, xmlNodePtr child, const char *name)
 {
-        char *current;
+        xmlChar *current;
         xmlNodePtr cur;
         const char * const *langs_pointer;
         const char  *gotlang = NULL; /*the highest language we got*/
@@ -231,12 +256,12 @@ get_i18n_string (xmlDocPtr doc, xmlNodePtr child, const char *name)
 
         /*find C the locale string*/
         for(cur = child->xmlChildrenNode; cur; cur = cur->next) {
-                char *lang;
+                xmlChar *lang;
                 if (cur->name == NULL ||
-                    g_strcasecmp (cur->name, name) != 0)
+                    g_ascii_strcasecmp ((const gchar *) cur->name, name) != 0)
                         continue;
 
-                lang = xmlGetProp (cur, "xml:lang");
+                lang = xmlGetProp (cur, (const xmlChar *) "xml:lang");
                 if (lang == NULL ||
                     lang[0] == '\0') {
                         if (lang != NULL)
@@ -247,7 +272,7 @@ get_i18n_string (xmlDocPtr doc, xmlNodePtr child, const char *name)
                                 xmlFree (current);
                         current = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);
                 } else {
-                        const char *ll = find_lang (langs_pointer, gotlang, lang);
+                        const char *ll = find_lang (langs_pointer, gotlang, (const gchar *) lang);
                         xmlFree (lang);
                         if (ll != NULL) {
                                 if (current != NULL)
@@ -278,9 +303,9 @@ read_hints_from_file (const char *file, GList *hintlist)
 	}
 
         for (cur = root->xmlChildrenNode; cur; cur = cur->next) {
-                char *str;
+                xmlChar *str;
                 if (cur->name == NULL ||
-                    g_strcasecmp (cur->name, "Hint") != 0)
+                    g_ascii_strcasecmp ((const gchar *) cur->name, "Hint") != 0)
                         continue;
                 str = get_i18n_string (doc, cur, "Content");
                 if (str != NULL) {
@@ -300,6 +325,13 @@ pick_random_hint(GnomeHint *gh)
         gh->_priv->curhint = g_list_nth (gh->_priv->hintlist, rnd);
 }
 
+/**
+ * gnome_hint_new
+ * 
+ * Description:
+ *
+ * Deprecated: 2.18:
+ */
 GtkWidget *
 gnome_hint_new (const gchar *hintfile,
 		const gchar *title,
@@ -331,7 +363,7 @@ gnome_hint_new (const gchar *hintfile,
                   "width", (double) gdk_pixbuf_get_width(im),
                   "height", (double) gdk_pixbuf_get_height(im),
                   NULL);
-       	gdk_pixbuf_unref(im);
+       	g_object_unref(im);
   	}
   }
   if (logo_image){
@@ -344,7 +376,7 @@ gnome_hint_new (const gchar *hintfile,
                   "width", (double) gdk_pixbuf_get_width(im),
                   "height", (double) gdk_pixbuf_get_height(im),
                   NULL);
-       	gdk_pixbuf_unref(im);
+       	g_object_unref(im);
   	}
   }
   if (!title) title="Gnome Hints";
@@ -403,3 +435,5 @@ gnome_hint_set_accessible_information (GnomeHint *gh, const gchar *name)
 		atk_object_set_name (aobj, name);
 	atk_object_set_description (aobj, (gchar *) gh->_priv->curhint->data);
 }
+
+#endif /* GNOME_DISABLE_DEPRECATED_SOURCE */
